

def add(num1, num2):
    add = num1 + num2
    x = f"value of addition: {num1} + {num2} = {add}"
    return x

def sub(num1,num2):
    sub1 = num1 - num2
    x = f"value of subtraction: {num1} - {num2} = {sub1}"
    return x

def mult(num1,num2):
    mul = num1 * num2
    x = f"value of multiplication: {num1} x {num2} = {mul}"
    return x

def div(num1,num2):
    div = num1 / num2
    x = f"value of division: {num1} / {num2} = {div}"
    return x





from setuptools import setup, find_packages

setup(
    name="smart_calculator",
    version="0.2",
    packages=find_packages(),
    install_requires=[
        # none for this version
    ],
    author="Chukwunonso Smart Agbawo",
    author_email= "chukwunonsosmartagbawo@gmail.com",
    maintainer="Chukwunonso Smart Agbawo",
    maintainer_email=  "chukwunonsosmartagbawo@gmail.com",
    entry_points={
        "console_scripts":[
            "addition = smart_calculator:addition",
            "subtraction = smart_calculator:sub",
            "multiplication = smart_calculator:mult",
        ],
    }
)